// XMLSetup.h: interface for the CXMLSetup class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_XMLSETUP_H__E14B5454_2EE5_11D3_8064_00105A1E5D53__INCLUDED_)
#define AFX_XMLSETUP_H__E14B5454_2EE5_11D3_8064_00105A1E5D53__INCLUDED_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

#undef DECL
#ifdef ENGINE_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif

/////////////////////////////////////////////////////////////////////////
//This class is used to retrieve tokens from NextGen XML file.
class CXMLSetup;        //fwd declare
class DECL CXMLToken
{
   friend class CXMLSetup;
public:
   CString GetTextStr(){return Text;};    //gets string ptr to token text
   LPTSTR GetText(){return (LPTSTR) (LPCTSTR) Text;};    //gets string ptr to token text
   CXMLToken();
   //these are the types we care about
   enum CTokenType{START_TAG = 0x01, END_TAG = 0x02, ATTR_NAME = 0x04, ATTR_TEXT = 0x08, COMMENT_TAG = 0x10, CONTENT = 0x20};
   int nType;

private:
   CString Text;
};

//////////////////////////////////////////////////////////////////////////
//This class is used to read in setup file.  The public functions
//are used by other modules to read and write to the setup file
//in our format
class DECL CXMLSetup
{
public:
   CXMLSetup();
   virtual ~CXMLSetup();

   //these functions write text and track tag level
   int WriteStartTag(CString Text);
   int WriteEndTag(CString Text);

   //these functions just write raw text
   void WriteText(CString Text);    // Converts &, >, and < to &amp;, &gt;, amd &lt;
   void WriteTag(CString Text);     // Does not touch &, >, and <

   //opens given filename
   BOOL OpenRead(LPCTSTR lpszFileName);
   BOOL OpenWrite(LPCTSTR lpszFileName);
   
   // Close the file explicitly.
   void Close();

   //used for navigating text
   BOOL ReadTagName(CString& lpszTag);
   void SkipWS();
   TCHAR GetNextChar();
   TCHAR LookNextChar();
   BOOL ReadAttrName(CString& lpszName);
   BOOL SkipPastEq();
   BOOL ReadAttrText(CString& lpszText);
   CString ReadNextToken(CXMLToken& XMLToken);

private:
   //states used in reading in tokens
   enum CState{LOOK_START = 0, LOOK_ATTR, LOOK_AFTER_START, LOOK_ATTR_TEXT};
   int nState;
   CString Text;    //buffer to hold token

   int nTagLevel;
   CFile file;
   CString filename;
   char * inbuf;                   //pts to whole file of data
   TCHAR * lpszSave;               //saves ptr so memory can be deleted
   TCHAR * ch;                             //tracks where we are in reading thru text

   //helper functions
   TCHAR * GetTextInQuotes(TCHAR * lpszIn, CString&  lpszText);
   TCHAR * SkipToAttrText(TCHAR * lpszIn);
   TCHAR * GetAttrName(TCHAR * lpszIn, CString& AttrName);
   TCHAR * SkipWhiteSpace(TCHAR * lpszIn);
   TCHAR * AdvanceToStartingBracket(TCHAR * lpszIn);
};

#endif // !defined(AFX_XMLSETUP_H__E14B5454_2EE5_11D3_8064_00105A1E5D53__INCLUDED_)
