/*
SerialCommClass.h

Serial Comm functions
*/

#ifndef _SDICOMMCLASS_H
#define _SDICOMMCLASS_H

#include "Xpert/Win32Fix.h"

#undef DECL
#ifdef SDI_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif

typedef unsigned char UCHAR;

class DECL CSDIComm
{
public:
   CSDIComm();
   ~CSDIComm();
   CSDIComm(CString CommPort);
   // open/close
   bool CloseComm();
   bool OpenComm();
   bool IsOpen();
   // configuration
   void SetConfiguration(DWORD BaudRate, BYTE ByteSize, BYTE Parity, BYTE StopBits, BOOL FlowCtrl);
   void SetCommPort (const CString CommPort) {m_CommPort = CommPort;};
   CString GetPortName() {return m_CommPort;};
   void SetBaudRate (const DWORD BaudRate) {m_BaudRate = BaudRate;};
   // data
   bool GetStr(UCHAR * Str, int StrLen);
   bool GetStr(UCHAR * Str) {return GetStr(Str, NumberBytesInputBuffer());};
   bool GetChar(UCHAR * Str);
   bool PutStr(const CString& CmdStr, bool SendBreak, DWORD BreakTime, DWORD MarkTime, DWORD& StartTime);
   int NumberBytesInputBuffer(); // returns number of bytes in input buffer
   bool KeyPressed();

   void SetRTS(){EscapeCommFunction(m_hPort, SETRTS);};
   void ClearRTS(){EscapeCommFunction(m_hPort, CLRRTS);};
   void SetDTR(){EscapeCommFunction(m_hPort, SETDTR);};
   void ClearDTR(){EscapeCommFunction(m_hPort, CLRDTR);};

   UCHAR MakeEvenParity(UCHAR Ch);
  
   BOOL SetBreak(){return SetCommBreak(m_hPort);};
   BOOL ClearBreak(){return ClearCommBreak(m_hPort);};
   bool m_ParityError;

   void FlushInput();
private:
   HANDLE  m_hPort;
   CString m_CommPort;
   DWORD   m_BaudRate;
   BOOL    m_FlowCtrl;     // Xon/Xoff
   BYTE    m_ByteSize;     // number of bits per byte (4-8)
   BYTE    m_Parity;       // 0-4 = no,odd,even,mark,space
   BYTE    m_StopBits;     // 0,1,2 = 1, 1.5, 2
};


#endif
