/*
SerialCommClass.h

Serial Comm functions
*/

#ifndef _SERIALCOMMCLASS_H
#define _SERIALCOMMCLASS_H

#include "Xpert/Win32Fix.h"

#undef DECL
#if defined(_WINDLL) || defined(XPERT_EXE)
#ifdef UTILS_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif
#else
#define DECL 
#endif

class DECL CSerialComm
{
public:
   CSerialComm();
   ~CSerialComm();
   CSerialComm(const TCHAR* CommPort);
   CSerialComm& operator=(const CSerialComm& SC);

   // open/close
   bool CloseComm();
   bool OpenComm();
   bool IsOpen() { return (m_hPort != INVALID_HANDLE_VALUE); };

   // configuration
   void SetConfiguration(DWORD BaudRate, BYTE ByteSize, BYTE Parity, BYTE StopBits, BOOL FlowCtrl);
   void SetCommPort(const TCHAR* CommPort) {WCSCPY(m_CommPort, CommPort);};
   void SetBaudRate(const DWORD BaudRate) {m_BaudRate = BaudRate;};
   void SetTimeouts(COMMTIMEOUTS& CommTimeouts) {m_CommTimeouts = CommTimeouts;};
   // data
#ifdef UNICODE
   bool GetChar(char  * ch) {return GetChar((UCHAR*) ch);};
#endif
   bool GetChar(UCHAR * uch);
   bool GetChar(TCHAR * wch);

   int  GetStr(UCHAR * Str, int StrLen);
#ifdef UNICODE
   int  GetStr(char *  Str, int StrLen) {return GetStr((UCHAR*)Str, StrLen);};
#endif
   int  GetStr(TCHAR * Str, int StrLen);
   int Get(void* Buffer, int BufferLen);
   int Get(void* Buffer, int BufferLen, DWORD dwTimeout);

   bool Put(const void* Buffer, int BufferLen);
   bool PutAndWait(const void* Buffer, int BufferLen);
#ifdef UNICODE
   bool PutChar(const char  ch) {return PutChar((const UCHAR)ch);};
#endif
   bool PutChar(const UCHAR uch);
   bool PutChar(const TCHAR wch);


#ifdef UNICODE
   bool PutStr(const char * Str) {return PutStr((UCHAR*)Str);};
   bool PutStr(const char * Str, int StrLen) {return PutStr((UCHAR*)Str, StrLen);};
#endif
   bool PutStr(const UCHAR * Str) {return (PutStr(Str, strlen((char*)Str)));};
   bool PutStr(const UCHAR * Str, int StrLen);
   bool PutStr(TCHAR * Str) { return PutStr(Str, WCSLEN(Str));};
   bool PutStr(TCHAR * Str, int StrLen);
   bool PutStr(CString Str);

   int  NumberBytesInputBuffer(); // returns number of bytes in input buffer
   bool KeyPressed();             // return true if a key is in rx buffer
   void FlushInput();             // empties rx buffer

   HANDLE GetHandle() {return m_hPort;};

   void WaitOnRx();                // waits (blocks) until a char comes in the serial port - flushes input first
   void WaitForTxEmpty();          // waits (blocks) until transmit buffer empty.
   void WaitForTxEmpty(TCHAR LastCh); // More accurate version of WaitForTxEmpty()


protected:
   HANDLE  m_hPort;
   TCHAR   m_CommPort[8];
   DWORD   m_BaudRate;
   BOOL    m_HardwareFlow; // None/Hardware
   BYTE    m_ByteSize;     // number of bits per byte (4-8)
   BYTE    m_Parity;       // 0-4 = no,odd,even,mark,space
   BYTE    m_StopBits;     // 0,1,2 = 1, 1.5, 2
   
   COMMTIMEOUTS m_CommTimeouts;

public:
   DWORD TotalPut;
   DWORD TotalGet;
};


#endif
