// Time.h: interface for the TTime class and other time-related functions.
//

#if !defined(_TTIME_H_)
#define _TTIME_H_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

#undef DECL
#if defined(_WINDLL) || defined(XPERT_EXE)
#ifdef UTILS_DLL
#define DECL _declspec(dllexport)
#else
#define DECL _declspec(dllimport)
#endif
#else
#define DECL 
#endif


///////////////////////////////////////////////////////////////////////////
// TTime class
//
class DECL TTime : public CTime
{
   // TTime is a derivation of CTime that maintains time to tick resolution.

   // CAUTION: This class is not intended to be the answer to all sub-second
   // time needs. Its primary purpose is to allow the capture and compare of
   // absolute tick times. Note that Format and CTimeSpan operations are
   // available but come from CTime which does not know about milliseconds.

   // Constructors and destructor.
   public:
   TTime() {m_dwMS = 0;};
   TTime(const CTime& ctime) : CTime(ctime) {m_dwMS = 0;};
   TTime (WORD wYear, WORD wMonth, WORD wDay, WORD wHour, WORD wMin, WORD wSec);
   private:
   TTime(const CTime& ctime, const DWORD dwMS);

   // Methods
   public:
   static TTime GetCurrentTime();
   DWORD GetMilliseconds() {return m_dwMS;};
   TTime& operator = (int i) {*dynamic_cast<CTime*>(this) = i; m_dwMS = 0; return *this;};
   TTime& operator = (const TTime& t);
   TTime operator + (DWORD dw) const;           // dw is in milliseconds
   TTime operator + (const CTimeSpan& cts) const;
   TTime operator + (const TTime& t) const;
   TTime& operator += (DWORD dw);               // dw is in milliseconds
   TTime& operator += (const CTimeSpan& cts);
   bool operator == (const TTime& t) const;
   bool operator != (const TTime& t) const;
   bool operator < (const TTime& t) const;
   bool operator > (const TTime& t) const;
   bool operator <= (const TTime& t) const;
   bool operator >= (const TTime& t) const;

   // Attributes
   protected:
   DWORD m_dwMS;
};


///////////////////////////////////////////////////////////////////////////
// Exported time-related functions
//
bool DECL ValidateDateTime(CString& strDateTime);
bool DECL ValidateDate(CString& strDate);
bool DECL ValidateTime(const CString& strTime, bool bMSec = false, bool m_b23HrLimit = false);
bool DECL ValidateInt(const CString& strInt, int iMin = INT_MIN, int iMax = INT_MAX);
DWORD DECL StrToMS(const CString& string);
CTimeSpan DECL StrToTimeSpan(const CString& string);
CTime DECL StrToTime(const CString& string);
CTime DECL NextScheduledTime(CTime TheTime, CTimeSpan Interval, CTimeSpan Offset);
DWORD DECL NextScheduledTime(DWORD TheTime, DWORD Interval, DWORD Offset);

#endif // !defined_TTIME_H_)
